@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-from .main import main
+from apex.main import main
 
 if __name__ == '__main__':
     main()
