@@ -4,6 +4,7 @@ from apex.core.calculator.VASP import VASP
 from dflow.python import upload_packages
 upload_packages.append(__file__)
 
+LAMMPS_TYPE = ["deepmd", "meam", "eam_fs", "eam_alloy"]
 
 def make_calculator(inter_parameter, path_to_poscar):
     """
@@ -14,7 +15,7 @@ def make_calculator(inter_parameter, path_to_poscar):
         return VASP(inter_parameter, path_to_poscar)
     elif inter_type == "abacus":
         return ABACUS(inter_parameter, path_to_poscar)
-    elif inter_type in ["deepmd", "meam", "eam_fs", "eam_alloy"]:
+    elif inter_type in LAMMPS_TYPE:
         return Lammps(inter_parameter, path_to_poscar)
     #    if inter_type == 'siesta':
     #        return Siesta(inter_parameter, path_to_poscar)
