@@ -11,8 +11,8 @@ from pymatgen.core.structure import Structure
 from pymatgen.core.surface import SlabGenerator
 from pymatgen.analysis.diffraction.tem import TEMCalculator
 
-import apex.core.calculator.lib.abacus as abacus
-import apex.core.calculator.lib.vasp as vasp
+from apex.core.calculator.lib import abacus_utils
+from apex.core.calculator.lib import vasp_utils
 from apex.core.property.Property import Property
 from apex.core.refine import make_refine
 from apex.core.reproduce import make_repro, post_repro
@@ -180,7 +180,7 @@ class Gamma(Property):
 
             else:
                 if self.inter_param["type"] == "abacus":
-                    CONTCAR = abacus.final_stru(path_to_equi)
+                    CONTCAR = abacus_utils.final_stru(path_to_equi)
                     POSCAR = "STRU"
                 else:
                     CONTCAR = "CONTCAR"
@@ -197,11 +197,11 @@ class Gamma(Property):
                 if self.inter_param["type"] == "abacus":
                     stru = dpdata.System(equi_contcar, fmt="stru")
                     stru.to("contcar", "CONTCAR.tmp")
-                    ptypes = vasp.get_poscar_types("CONTCAR.tmp")
+                    ptypes = vasp_utils.get_poscar_types("CONTCAR.tmp")
                     ss = Structure.from_file("CONTCAR.tmp")
                     os.remove("CONTCAR.tmp")
                 else:
-                    ptypes = vasp.get_poscar_types(equi_contcar)
+                    ptypes = vasp_utils.get_poscar_types(equi_contcar)
                     # read structure from relaxed CONTCAR
                     ss = Structure.from_file(equi_contcar)
 
@@ -286,10 +286,10 @@ class Gamma(Property):
                     )
                     # make confs
                     obtained_slab.to("POSCAR.tmp", "POSCAR")
-                    vasp.regulate_poscar("POSCAR.tmp", "POSCAR")
-                    vasp.sort_poscar("POSCAR", "POSCAR", ptypes)
+                    vasp_utils.regulate_poscar("POSCAR.tmp", "POSCAR")
+                    vasp_utils.sort_poscar("POSCAR", "POSCAR", ptypes)
                     if self.inter_param["type"] == "abacus":
-                        abacus.poscar2stru("POSCAR", self.inter_param, "STRU")
+                        abacus_utils.poscar2stru("POSCAR", self.inter_param, "STRU")
                         os.remove("POSCAR")
                     # vasp.perturb_xz('POSCAR', 'POSCAR', self.pert_xz)
                     # record miller
